summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kolibs/KoPageLayoutSize.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kolibs/KoPageLayoutSize.h')
-rw-r--r--kexi/3rdparty/kolibs/KoPageLayoutSize.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/kexi/3rdparty/kolibs/KoPageLayoutSize.h b/kexi/3rdparty/kolibs/KoPageLayoutSize.h
index e32f9670..3f46def2 100644
--- a/kexi/3rdparty/kolibs/KoPageLayoutSize.h
+++ b/kexi/3rdparty/kolibs/KoPageLayoutSize.h
@@ -17,37 +17,38 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef kopagelayoutsize_h
-#define kopagelayoutsize_h
+#ifndef kopagetqlayoutsize_h
+#define kopagetqlayoutsize_h
-#include <qgroupbox.h>
+#include <tqgroupbox.h>
#include <KoGlobal.h>
#include <KoUnit.h>
#include <kdialogbase.h>
#include <KoPageLayout.h>
#include <KoPageLayoutDia.h>
-class QComboBox;
+class TQComboBox;
class KoUnitDoubleSpinBox;
class KoPageLayoutColumns;
/**
* This class is a widget that shows the KoPageLayout data structure and allows the user to change it.
*/
-class KoPageLayoutSize : public QWidget {
+class KoPageLayoutSize : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Contructor
* @param parent the parent widget
* @param layout the page layout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
* @param unitChooser if true a combobox with the unit-type is shown for the user to change
* @param enableBorders if true enable the user to change the margins (aka borders) of the page
*/
- KoPageLayoutSize(QWidget *parent, const KoPageLayout& layout, KoUnit::Unit unit,
+ KoPageLayoutSize(TQWidget *tqparent, const KoPageLayout& tqlayout, KoUnit::Unit unit,
const KoColumns& columns, bool unitChooser, bool enableBorders);
/**
@@ -75,15 +76,15 @@ public slots:
signals:
/**
* Emitted whenever the user changed something in the dialog.
* @param layout the update layout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)
*/
- void propertyChange(KoPageLayout &layout);
+ void propertyChange(KoPageLayout &tqlayout);
protected:
- QComboBox *cpgUnit;
- QComboBox *cpgFormat;
+ TQComboBox *cpgUnit;
+ TQComboBox *cpgFormat;
KoUnitDoubleSpinBox *epgWidth;
KoUnitDoubleSpinBox *epgHeight;
KoUnitDoubleSpinBox *ebrLeft;
@@ -91,7 +92,7 @@ protected:
KoUnitDoubleSpinBox *ebrTop;
KoUnitDoubleSpinBox *ebrBottom;
KoPagePreview *pgPreview;
- QButtonGroup *m_orientGroup;
+ TQButtonGroup *m_orientGroup;
protected slots:
void formatChanged( int );
@@ -17,37 +17,38 @@
/**
* Contructor
- * @param parent the parent widget
- * @param layout the page layout that this widget should be initialzed with.
+ * @param tqparent the tqparent widget
+ * @param tqlayout the page tqlayout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
@@ -75,15 +76,15 @@ public slots:
/**
* Emitted whenever the user changed something in the dialog.
- * @param layout the update layout structure with currently displayed info.
+ * @param tqlayout the update tqlayout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)